@@ -509,13 +509,13 @@ nd_queue_finalize (GObject *object)
         }
 
         g_hash_table_destroy (queue->priv->notifications);
+        g_hash_table_destroy (queue->priv->bubbles);
         g_queue_free (queue->priv->queue);
 
         destroy_screen (queue);
 
-        if (queue->priv->numerable_icon != NULL) {
-                g_object_unref (queue->priv->numerable_icon);
-        }
+        g_clear_object (&queue->priv->numerable_icon);
+        g_clear_object (&queue->priv->status_icon);
 
         G_OBJECT_CLASS (nd_queue_parent_class)->finalize (object);
 }
